==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/vai.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "vai",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Vai",
  month_format_abbreviated => [
    "\N{U+a5a8}\N{U+a56a}\N{U+a583}",
    "\N{U+a552}\N{U+a561}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}",
    "\N{U+a5a8}\N{U+a56a}\N{U+a571}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+a5a8}\N{U+a56a}\N{U+a583} \N{U+a51e}\N{U+a56e}",
    "\N{U+a552}\N{U+a561}\N{U+a59d}\N{U+a595}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}\N{U+a524}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}\N{U+a554}\N{U+a57f} \N{U+a578}\N{U+a583}\N{U+a5cf}",
    "\N{U+a5a8}\N{U+a56a}\N{U+a571} \N{U+a5cf}\N{U+a56e}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+a5a8}\N{U+a56a}\N{U+a583}",
    "\N{U+a552}\N{U+a561}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}",
    "\N{U+a5a8}\N{U+a56a}\N{U+a571}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+a5a8}\N{U+a56a}\N{U+a583} \N{U+a51e}\N{U+a56e}",
    "\N{U+a552}\N{U+a561}\N{U+a59d}\N{U+a595}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}\N{U+a524}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}\N{U+a554}\N{U+a57f} \N{U+a578}\N{U+a583}\N{U+a5cf}",
    "\N{U+a5a8}\N{U+a56a}\N{U+a571} \N{U+a5cf}\N{U+a56e}",
  ],
  name => "Vai",
  native_language => "\N{U+a559}\N{U+a524}",
  native_name => "\N{U+a559}\N{U+a524}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.24.orig.tar.gz: DateTime-Locale-1.24/share/vai.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "vai",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+a5f3}\N{U+a5e1}\N{U+a609}",
    "\N{U+a55a}\N{U+a55e}\N{U+a55a}",
    "\N{U+a549}\N{U+a55e}\N{U+a552}",
    "\N{U+a549}\N{U+a524}\N{U+a546}\N{U+a562}",
    "\N{U+a549}\N{U+a524}\N{U+a540}\N{U+a56e}",
    "\N{U+a53b}\N{U+a52c}\N{U+a533}",
    "\N{U+a55e}\N{U+a54c}\N{U+a535}",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Vai",
  month_format_abbreviated => [
    "\N{U+a5a8}\N{U+a595}\N{U+a51e}",
    "\N{U+a552}\N{U+a561}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}",
    "\N{U+a5a8}\N{U+a595}\N{U+a5cf}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+a5a8}\N{U+a595} \N{U+a56a}\N{U+a574} \N{U+a51e}\N{U+a500}\N{U+a56e}\N{U+a54a}",
    "\N{U+a552}\N{U+a561}\N{U+a59d}\N{U+a595}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}\N{U+a524}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}\N{U+a554}\N{U+a57f} \N{U+a578}\N{U+a583}\N{U+a5cf}",
    "\N{U+a5a8}\N{U+a595} \N{U+a56a}\N{U+a574} \N{U+a5cf}\N{U+a5ba}\N{U+a56e}\N{U+a54a}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+a5a8}\N{U+a595}\N{U+a51e}",
    "\N{U+a552}\N{U+a561}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}",
    "\N{U+a5a8}\N{U+a595}\N{U+a5cf}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+a5a8}\N{U+a595} \N{U+a56a}\N{U+a574} \N{U+a51e}\N{U+a500}\N{U+a56e}\N{U+a54a}",
    "\N{U+a552}\N{U+a561}\N{U+a59d}\N{U+a595}",
    "\N{U+a57e}\N{U+a5ba}",
    "\N{U+a5a2}\N{U+a595}",
    "\N{U+a591}\N{U+a571}",
    "\N{U+a5b1}\N{U+a60b}",
    "\N{U+a5b1}\N{U+a55e}\N{U+a524}",
    "\N{U+a5db}\N{U+a515}",
    "\N{U+a562}\N{U+a54c}",
    "\N{U+a56d}\N{U+a583}",
    "\N{U+a51e}\N{U+a60b}\N{U+a554}\N{U+a57f} \N{U+a578}\N{U+a583}\N{U+a5cf}",
    "\N{U+a5a8}\N{U+a595} \N{U+a56a}\N{U+a574} \N{U+a5cf}\N{U+a5ba}\N{U+a56e}\N{U+a54a}",
  ],
  name => "Vai",
  native_language => "\N{U+a559}\N{U+a524}",
  native_name => "\N{U+a559}\N{U+a524}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 35,
}
